<?php

function display_attachments()
{
	global $context, $options, $txt;

	$attachments = get_recent_attachments(6, array('jpg', 'jpeg', 'png', 'gif', 'bmp'));
	$hide = $context['user']['is_guest'] ? !empty($_COOKIE['board_attach']) : !empty($options['board_attach']);

	echo '
<div id="board_attach_holder">
	<a href="#attach_toggle" onclick="attach_toggle(); return false;" id="attach_toggle">', !empty($hide) ? $txt['ba_show'] : $txt['ba_hide'], '</a>
	<div id="board_attach_content"', !empty($hide) ? ' style="display: none;"' : '', '>';

	if (empty($attachments))
		echo $txt['ba_none'];
	else
	{
		echo '
		<table>
			<tr>';

		foreach ($attachments as $attachment)
		{
			echo '
				<td><a href="', $attachment['topic']['href'], '">', $attachment['file']['image']['thumb'], '</a></td>';
		}

		echo '
			</tr>
		</table>';
	}

	echo '
	</div>
</div>
<script type="text/javascript">
	function attach_toggle()
	{
		var container = document.getElementById(\'board_attach_content\');
		var toggle = document.getElementById(\'attach_toggle\');
		var mode = container.style.display == \'none\' ? 0 : 1;

		if (mode == 0)
		{
			container.style.display = \'\';
			setInnerHTML(toggle, \'', $txt['ba_hide'], '\');
		}
		else
		{
			container.style.display = \'none\';
			setInnerHTML(toggle, \'', $txt['ba_show'], '\');
		}';

	if ($context['user']['is_guest'])
	{
		echo '
		document.cookie = \'board_attach=\' + mode;';
	}
	else
	{
		echo '
		smf_setThemeOption(\'board_attach\', mode, null, "' . $context['session_id'] . '", "' . $context['session_var'] . '");';
	}

	echo '
	}
</script>';
}

function get_recent_attachments($num_attachments = 10, $attachment_ext = array())
{
	global $smcFunc, $context, $modSettings, $scripturl, $txt, $settings;

	$attachments_boards = boardsAllowedTo('view_attachments');

	if (empty($attachments_boards))
		return array();

	if (!is_array($attachment_ext))
		$attachment_ext = array($attachment_ext);

	$request = $smcFunc['db_query']('', '
		SELECT
			att.id_attach, att.id_msg, att.filename, IFNULL(att.size, 0) AS filesize, att.downloads, mem.id_member,
			IFNULL(mem.real_name, m.poster_name) AS poster_name, m.id_topic, m.subject, t.id_board, m.poster_time,
			att.width, att.height' . (empty($modSettings['attachmentShowImages']) || empty($modSettings['attachmentThumbnails']) ? '' : ', IFNULL(thumb.id_attach, 0) AS id_thumb, thumb.width AS thumb_width, thumb.height AS thumb_height') . '
		FROM {db_prefix}attachments AS att
			INNER JOIN {db_prefix}messages AS m ON (m.id_msg = att.id_msg)
			INNER JOIN {db_prefix}topics AS t ON (t.id_topic = m.id_topic)
			LEFT JOIN {db_prefix}members AS mem ON (mem.id_member = m.id_member)' . (empty($modSettings['attachmentShowImages']) || empty($modSettings['attachmentThumbnails']) ? '' : '
			LEFT JOIN {db_prefix}attachments AS thumb ON (thumb.id_attach = att.id_thumb)') . '
		WHERE att.attachment_type = 0' . ($attachments_boards === array(0) ? '' : '
			AND m.id_board IN ({array_int:boards_can_see})') . (!empty($attachment_ext) ? '
			AND att.fileext IN ({array_string:attachment_ext})' : '') .
			(!$modSettings['postmod_active'] || allowedTo('approve_posts') ? '' : '
			AND t.approved = {int:is_approved}
			AND m.approved = {int:is_approved}
			AND att.approved = {int:is_approved}') . '
		ORDER BY RAND()
		LIMIT {int:num_attachments}',
		array(
			'boards_can_see' => $attachments_boards,
			'attachment_ext' => $attachment_ext,
			'num_attachments' => $num_attachments,
			'is_approved' => 1,
		)
	);

	$attachments = array();
	while ($row = $smcFunc['db_fetch_assoc']($request))
	{
		$filename = preg_replace('~&amp;#(\\d{1,7}|x[0-9a-fA-F]{1,6});~', '&#\\1;', htmlspecialchars($row['filename']));

		$attachments[$row['id_attach']] = array(
			'member' => array(
				'id' => $row['id_member'],
				'name' => $row['poster_name'],
				'link' => empty($row['id_member']) ? $row['poster_name'] : '<a href="' . $scripturl . '?action=profile;u=' . $row['id_member'] . '">' . $row['poster_name'] . '</a>',
			),
			'file' => array(
				'filename' => $filename,
				'filesize' => round($row['filesize'] /1024, 2) . $txt['kilobyte'],
				'downloads' => $row['downloads'],
				'href' => $scripturl . '?action=dlattach;topic=' . $row['id_topic'] . '.0;attach=' . $row['id_attach'],
				'link' => '<img src="' . $settings['images_url'] . '/icons/clip.gif" alt="" /> <a href="' . $scripturl . '?action=dlattach;topic=' . $row['id_topic'] . '.0;attach=' . $row['id_attach'] . '">' . $filename . '</a>',
				'is_image' => !empty($row['width']) && !empty($row['height']) && !empty($modSettings['attachmentShowImages']),
			),
			'topic' => array(
				'id' => $row['id_topic'],
				'subject' => $row['subject'],
				'href' => $scripturl . '?topic=' . $row['id_topic'] . '.msg' . $row['id_msg'] . '#msg' . $row['id_msg'],
				'link' => '<a href="' . $scripturl . '?topic=' . $row['id_topic'] . '.msg' . $row['id_msg'] . '#msg' . $row['id_msg'] . '">' . $row['subject'] . '</a>',
				'time' => timeformat($row['poster_time']),
			),
		);

		if ($attachments[$row['id_attach']]['file']['is_image'])
		{
			$id_thumb = empty($row['id_thumb']) ? $row['id_attach'] : $row['id_thumb'];
			$attachments[$row['id_attach']]['file']['image'] = array(
				'id' => $id_thumb,
				'width' => $row['width'],
				'height' => $row['height'],
				'img' => '<img src="' . $scripturl . '?action=dlattach;topic=' . $row['id_topic'] . '.0;attach=' . $row['id_attach'] . ';image" alt="' . $filename . '" />',
				'thumb' => '<img src="' . $scripturl . '?action=dlattach;topic=' . $row['id_topic'] . '.0;attach=' . $id_thumb . ';image" alt="' . $filename . '" />',
				'href' => $scripturl . '?action=dlattach;topic=' . $row['id_topic'] . '.0;attach=' . $id_thumb . ';image',
				'link' => '<a href="' . $scripturl . '?action=dlattach;topic=' . $row['id_topic'] . '.0;attach=' . $row['id_attach'] . ';image"><img src="' . $scripturl . '?action=dlattach;topic=' . $row['id_topic'] . '.0;attach=' . $id_thumb . ';image" alt="' . $filename . '" /></a>',
			);
		}
	}
	$smcFunc['db_free_result']($request);

	return $attachments;
}

?>